==============================
User Guide
==============================

This guide will help you to install ExoRad, to use it as
a standalone program and to understand the library.

.. toctree::
    :maxdepth: 2

    Installation <installation>
    Quickstart guide <quickstart_guide>
    Introduction <introduction>
    Inputs <inputs>
    Outputs <outputs>
    Prepare Payload <prepare_payload>
    Prepare Optics <prepare_optics>
    Prepare Target <prepare_target>
    Light & Noise <light_and_noise>

* :ref:`genindex`